--- dovecot-1.1.1-orig/configure.in	2008-06-22 13:02:27.000000000 +0200
+++ dovecot-1.1.1/configure.in	2008-07-06 18:35:07.000000000 +0200
@@ -19,7 +19,8 @@
   sys/uio.h sys/sysmacros.h sys/resource.h sys/select.h libgen.h \
   sys/quota.h sys/fs/ufs_quota.h ufs/ufs/quota.h jfs/quota.h sys/fs/quota_common.h \
   mntent.h sys/mnttab.h sys/event.h sys/time.h sys/mkdev.h linux/dqblk_xfs.h \
-  xfs/xqm.h sasl.h sasl/sasl.h execinfo.h ucontext.h malloc_np.h)
+  xfs/xqm.h sasl.h sasl/sasl.h execinfo.h ucontext.h malloc_np.h \
+  sys/vmount.h)
 
 AC_ARG_ENABLE(ipv6,
 [  --enable-ipv6           Enable IPv6 support (auto)],
@@ -1480,6 +1481,38 @@
 fi
 
 dnl **
+dnl ** AIX mntctl
+dnl **
+
+if test $ac_cv_header_sys_vmount_h = yes; then
+
+AC_MSG_CHECKING([for reasonable mntctl buffer size])
+AC_RUN_IFELSE([AC_LANG_SOURCE([[
+      #include <stdio.h>
+      #include <stdlib.h>
+      #include <sys/vmount.h>
+      int main() {
+    int size,count; char *m;
+    FILE *f=fopen("conftestval", "w");
+    if (!f) exit(1);
+    if ((count=mntctl(MCTL_QUERY,sizeof(size),&size))!=0 || !(m=malloc(size)) ||
+        (count=mntctl(MCTL_QUERY,size,m))<=0) exit(1);
+    fprintf(f, "%d\n",(size * (count + 5))/count & ~1); /* 5 mounts more */
+    exit(0);
+      }
+    ]])],[
+      size=`cat conftestval`
+      rm -f conftestval
+      AC_DEFINE_UNQUOTED(STATIC_MTAB_SIZE,$size, reasonable mntctl buffer size)
+      AC_MSG_RESULT($size)
+    ],[
+	  AC_MSG_RESULT(default)
+    ],[])
+
+fi
+
+
+dnl **
 dnl ** SSL
 dnl **
 
--- dovecot-1.1.1-orig/src/lib/mountpoint.c	2008-06-12 08:45:10.000000000 +0200
+++ dovecot-1.1.1/src/lib/mountpoint.c	2008-07-06 18:06:18.000000000 +0200
@@ -5,7 +5,10 @@
 
 #include <sys/stat.h>
 
-#ifdef HAVE_STATVFS_MNTFROMNAME
+#ifdef HAVE_SYS_VMOUNT_H
+#  include <stdio.h>
+#  include <sys/vmount.h> /* AIX */
+#elif defined(HAVE_STATVFS_MNTFROMNAME)
 #  include <sys/statvfs.h> /* NetBSD 3.0+, FreeBSD 5.0+ */
 #  define STATVFS_STR "statvfs"
 #elif defined(HAVE_STATFS_MNTFROMNAME)
@@ -37,6 +40,12 @@
 #ifndef MNTTYPE_IGNORE
 #  define MNTTYPE_IGNORE "ignore"
 #endif
+#ifndef MNTTYPE_JFS
+#  define MNTTYPE_JFS "jfs"
+#endif
+#ifndef MNTTYPE_NFS
+#  define MNTTYPE_NFS "nfs"
+#endif
 
 
 int mountpoint_get(const char *path, pool_t pool, struct mountpoint *point_r)
@@ -93,7 +102,66 @@
 	}
 	block_size = st.st_blksize;
 
-#ifdef HAVE_SYS_MNTTAB_H
+#ifdef HAVE_SYS_VMOUNT_H
+
+#ifndef STATIC_MTAB_SIZE
+#  define STATIC_MTAB_SIZE 512
+#endif
+{
+	char static_mtab[STATIC_MTAB_SIZE], *mtab = static_mtab;
+	int i, count;
+	struct vmount *vmt;
+
+	count = mntctl(MCTL_QUERY, sizeof(static_mtab), mtab);
+	if (count == 0) {
+
+		int size = *(int *)mtab;
+		i_error("(info) mntctl needs %d bytes, allocating", size);
+
+		mtab  = t_malloc(size);
+		count = mntctl(MCTL_QUERY, size, mtab);
+		if (count == 0) {
+
+			i_error("mntctl failed, size has changed!");
+			return -1;
+		}
+	}
+	for (i = 0; i < count && device_path == NULL; i++) {
+
+		struct stat vst;
+		char *vmt_object, *vmt_stub, *vmt_hostname;
+
+		vmt = (struct vmount *)(i == 0 ? mtab : (((char *)vmt) + vmt->vmt_length));
+		vmt_hostname = ((char *)vmt) + vmt->vmt_data[VMT_HOSTNAME].vmt_off;
+		vmt_object   = ((char *)vmt) + vmt->vmt_data[VMT_OBJECT].vmt_off;
+		vmt_stub     = ((char *)vmt) + vmt->vmt_data[VMT_STUB].vmt_off;
+
+		switch (vmt->vmt_gfstype) {
+
+			case MNT_NFS:
+			case MNT_NFS3:
+			case MNT_NFS4:
+			case MNT_RFS4:
+				if (stat(vmt_stub,&vst) >= 0 && st.st_dev == vst.st_dev) {
+					device_path = t_strconcat(vmt_hostname, ":", vmt_object, NULL);
+					mount_path  = vmt_stub;
+					type        = MNTTYPE_NFS;
+				}
+				break;
+
+			case MNT_J2:
+			case MNT_JFS:
+				if (stat(vmt_stub,&vst) >= 0 && st.st_dev == vst.st_dev) {
+					device_path = vmt_object;
+					mount_path  = vmt_stub;
+					type        = MNTTYPE_JFS;
+				}
+				break;
+		}
+	}
+}
+#elif defined(HAVE_SYS_MNTTAB_H)
+
 	/* Solaris */
 	f = fopen(MTAB_PATH, "r");
 	if (f == NULL) {
